@@ -5,6 +5,16 @@ from .registry import registry
 from .utils.deprecation import RemovedInWillow05Warning
 
 
+try:
+    imghdr.test_webp
+except AttributeError:
+    # Add in webp test for 2.7 and 3.5, see http://bugs.python.org/issue20197
+    def test_webp(h, f):
+        if h.startswith(b'RIFF') and h[8:12] == b'WEBP':
+            return 'webp'
+    imghdr.tests.append(test_webp)
+
+
 class UnrecognisedImageFormatError(IOError):
     pass
 
@@ -82,7 +92,7 @@ class Image(object):
 
     def save(self, image_format, output):
         # Get operation name
-        if image_format not in ['jpeg', 'png', 'gif', 'bmp', 'tiff']:
+        if image_format not in ['jpeg', 'png', 'gif', 'bmp', 'tiff', 'webp']:
             raise ValueError("Unknown image format: %s" % image_format)
 
         operation_name = 'save_as_' + image_format
@@ -158,6 +168,10 @@ class TIFFImageFile(ImageFile):
     format_name = 'tiff'
 
 
+class WebPImageFile(ImageFile):
+    format_name = 'webp'
+
+
 INITIAL_IMAGE_CLASSES = {
     # A mapping of image formats to their initial class
     'jpeg': JPEGImageFile,
@@ -165,6 +179,7 @@ INITIAL_IMAGE_CLASSES = {
     'gif': GIFImageFile,
     'bmp': BMPImageFile,
     'tiff': TIFFImageFile,
+    'webp': WebPImageFile,
 }
 
 
